'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _Label = require('./Label');

var _Label2 = _interopRequireDefault(_Label);

var _Text = require('./Text');

var _Text2 = _interopRequireDefault(_Text);

var _theme = require('./theme');

var _theme2 = _interopRequireDefault(_theme);

var _margins = require('./util/margins');

var _margins2 = _interopRequireDefault(_margins);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/**
 * Textarea form element with label
 */

var Textarea = function Textarea(_ref, _ref2) {
  var label = _ref.label;
  var name = _ref.name;
  var style = _ref.style;
  var message = _ref.message;
  var hideLabel = _ref.hideLabel;
  var children = _ref.children;

  var props = _objectWithoutProperties(_ref, ['label', 'name', 'style', 'message', 'hideLabel', 'children']);

  var rebass = _ref2.rebass;

  var config = _extends({}, _theme2.default, rebass);
  var customStyle = rebass ? rebass.Textarea : {};
  var scale = config.scale;
  var colors = config.colors;
  var borderColor = config.borderColor;


  var otherStyle = _extends({}, customStyle, style);

  var invalid = props['aria-invalid'] || props.invalid;

  var sx = {
    root: _extends({
      marginBottom: scale[2],
      color: invalid ? colors.error : null
    }, (0, _margins2.default)(props, scale)),
    textarea: _extends({
      fontFamily: 'inherit',
      fontSize: 'inherit',
      boxSizing: 'border-box',
      display: 'block',
      width: '100%',
      margin: 0,
      padding: 8,
      borderRadius: 2,
      borderWidth: 1,
      borderStyles: 'solid',
      borderColor: borderColor
    }, otherStyle)
  };

  var cx = (0, _classnames2.default)('Textarea', {
    'is-invalid': invalid,
    'is-disabled': props.disabled,
    'is-readonly': props.readOnly
  });

  return _react2.default.createElement(
    'div',
    { className: cx,
      style: sx.root },
    _react2.default.createElement(_Label2.default, {
      htmlFor: name,
      hide: hideLabel,
      children: label }),
    _react2.default.createElement('textarea', _extends({}, props, {
      name: name,
      style: sx.textarea })),
    message && _react2.default.createElement(_Text2.default, { small: true, children: message })
  );
};

Textarea.propTypes = {
  /** Label for form element */
  label: _react2.default.PropTypes.string.isRequired,
  /** Name attribute for form element */
  name: _react2.default.PropTypes.string.isRequired,
  /** Adds a helper or error message below the textarea */
  message: _react2.default.PropTypes.string,
  /** Hides the form element label */
  hideLabel: _react2.default.PropTypes.bool
};

Textarea.contextTypes = {
  rebass: _react2.default.PropTypes.object
};

exports.default = Textarea;